==> zio-aws-fms_2.13-5.17.271.1-sources.jar: zio/aws/fms/model/NetworkFirewallMissingSubnetViolation.scala <==
package zio.aws.fms.model
import zio.ZIO
import zio.aws.fms.model.primitives.{
  TargetViolationReason,
  LengthBoundedString,
  ResourceId,
  ViolationTarget
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class NetworkFirewallMissingSubnetViolation(
    violationTarget: Optional[ViolationTarget] = Optional.Absent,
    vpc: Optional[ResourceId] = Optional.Absent,
    availabilityZone: Optional[LengthBoundedString] = Optional.Absent,
    targetViolationReason: Optional[TargetViolationReason] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fms.model.NetworkFirewallMissingSubnetViolation = {
    import NetworkFirewallMissingSubnetViolation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fms.model.NetworkFirewallMissingSubnetViolation
      .builder()
      .optionallyWith(
        violationTarget.map(value =>
          ViolationTarget.unwrap(value): java.lang.String
        )
      )(_.violationTarget)
      .optionallyWith(
        vpc.map(value => ResourceId.unwrap(value): java.lang.String)
      )(_.vpc)
      .optionallyWith(
        availabilityZone.map(value =>
          LengthBoundedString.unwrap(value): java.lang.String
        )
      )(_.availabilityZone)
      .optionallyWith(
        targetViolationReason.map(value =>
          TargetViolationReason.unwrap(value): java.lang.String
        )
      )(_.targetViolationReason)
      .build()
  }
  def asReadOnly
      : zio.aws.fms.model.NetworkFirewallMissingSubnetViolation.ReadOnly =
    zio.aws.fms.model.NetworkFirewallMissingSubnetViolation
      .wrap(buildAwsValue())
}
object NetworkFirewallMissingSubnetViolation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fms.model.NetworkFirewallMissingSubnetViolation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.fms.model.NetworkFirewallMissingSubnetViolation =
      zio.aws.fms.model.NetworkFirewallMissingSubnetViolation(
        violationTarget.map(value => value),
        vpc.map(value => value),
        availabilityZone.map(value => value),
        targetViolationReason.map(value => value)
      )
    def violationTarget: Optional[ViolationTarget]
    def vpc: Optional[ResourceId]
    def availabilityZone: Optional[LengthBoundedString]
    def targetViolationReason: Optional[TargetViolationReason]
    def getViolationTarget: ZIO[Any, AwsError, ViolationTarget] =
      AwsError.unwrapOptionField("violationTarget", violationTarget)
    def getVpc: ZIO[Any, AwsError, ResourceId] =
      AwsError.unwrapOptionField("vpc", vpc)
    def getAvailabilityZone: ZIO[Any, AwsError, LengthBoundedString] =
      AwsError.unwrapOptionField("availabilityZone", availabilityZone)
    def getTargetViolationReason: ZIO[Any, AwsError, TargetViolationReason] =
      AwsError.unwrapOptionField("targetViolationReason", targetViolationReason)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fms.model.NetworkFirewallMissingSubnetViolation
  ) extends zio.aws.fms.model.NetworkFirewallMissingSubnetViolation.ReadOnly {
    override val violationTarget: Optional[ViolationTarget] =
      zio.aws.core.internal
        .optionalFromNullable(impl.violationTarget())
        .map(value => zio.aws.fms.model.primitives.ViolationTarget(value))
    override val vpc: Optional[ResourceId] = zio.aws.core.internal
      .optionalFromNullable(impl.vpc())
      .map(value => zio.aws.fms.model.primitives.ResourceId(value))
    override val availabilityZone: Optional[LengthBoundedString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.availabilityZone())
        .map(value => zio.aws.fms.model.primitives.LengthBoundedString(value))
    override val targetViolationReason: Optional[TargetViolationReason] =
      zio.aws.core.internal
        .optionalFromNullable(impl.targetViolationReason())
        .map(value => zio.aws.fms.model.primitives.TargetViolationReason(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.fms.model.NetworkFirewallMissingSubnetViolation
  ): zio.aws.fms.model.NetworkFirewallMissingSubnetViolation.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-fms_3-5.17.157.2-sources.jar: zio/aws/fms/model/NetworkFirewallMissingSubnetViolation.scala <==
package zio.aws.fms.model
import zio.ZIO
import zio.aws.fms.model.primitives.{
  TargetViolationReason,
  LengthBoundedString,
  ResourceId,
  ViolationTarget
}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class NetworkFirewallMissingSubnetViolation(
    violationTarget: Option[ViolationTarget] = None,
    vpc: Option[ResourceId] = None,
    availabilityZone: Option[LengthBoundedString] = None,
    targetViolationReason: Option[TargetViolationReason] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fms.model.NetworkFirewallMissingSubnetViolation = {
    import NetworkFirewallMissingSubnetViolation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fms.model.NetworkFirewallMissingSubnetViolation
      .builder()
      .optionallyWith(
        violationTarget.map(value =>
          ViolationTarget.unwrap(value): java.lang.String
        )
      )(_.violationTarget)
      .optionallyWith(
        vpc.map(value => ResourceId.unwrap(value): java.lang.String)
      )(_.vpc)
      .optionallyWith(
        availabilityZone.map(value =>
          LengthBoundedString.unwrap(value): java.lang.String
        )
      )(_.availabilityZone)
      .optionallyWith(
        targetViolationReason.map(value =>
          TargetViolationReason.unwrap(value): java.lang.String
        )
      )(_.targetViolationReason)
      .build()
  }
  def asReadOnly
      : zio.aws.fms.model.NetworkFirewallMissingSubnetViolation.ReadOnly =
    zio.aws.fms.model.NetworkFirewallMissingSubnetViolation
      .wrap(buildAwsValue())
}
object NetworkFirewallMissingSubnetViolation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fms.model.NetworkFirewallMissingSubnetViolation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.fms.model.NetworkFirewallMissingSubnetViolation =
      zio.aws.fms.model.NetworkFirewallMissingSubnetViolation(
        violationTarget.map(value => value),
        vpc.map(value => value),
        availabilityZone.map(value => value),
        targetViolationReason.map(value => value)
      )
    def violationTarget: Option[ViolationTarget]
    def vpc: Option[ResourceId]
    def availabilityZone: Option[LengthBoundedString]
    def targetViolationReason: Option[TargetViolationReason]
    def getViolationTarget: ZIO[Any, AwsError, ViolationTarget] =
      AwsError.unwrapOptionField("violationTarget", violationTarget)
    def getVpc: ZIO[Any, AwsError, ResourceId] =
      AwsError.unwrapOptionField("vpc", vpc)
    def getAvailabilityZone: ZIO[Any, AwsError, LengthBoundedString] =
      AwsError.unwrapOptionField("availabilityZone", availabilityZone)
    def getTargetViolationReason: ZIO[Any, AwsError, TargetViolationReason] =
      AwsError.unwrapOptionField("targetViolationReason", targetViolationReason)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fms.model.NetworkFirewallMissingSubnetViolation
  ) extends zio.aws.fms.model.NetworkFirewallMissingSubnetViolation.ReadOnly {
    override val violationTarget: Option[ViolationTarget] = scala
      .Option(impl.violationTarget())
      .map(value => zio.aws.fms.model.primitives.ViolationTarget(value))
    override val vpc: Option[ResourceId] = scala
      .Option(impl.vpc())
      .map(value => zio.aws.fms.model.primitives.ResourceId(value))
    override val availabilityZone: Option[LengthBoundedString] = scala
      .Option(impl.availabilityZone())
      .map(value => zio.aws.fms.model.primitives.LengthBoundedString(value))
    override val targetViolationReason: Option[TargetViolationReason] = scala
      .Option(impl.targetViolationReason())
      .map(value => zio.aws.fms.model.primitives.TargetViolationReason(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.fms.model.NetworkFirewallMissingSubnetViolation
  ): zio.aws.fms.model.NetworkFirewallMissingSubnetViolation.ReadOnly =
    new Wrapper(impl)
}
